@@ -88,52 +88,6 @@ print.massvectorlist<-function(x,...)
 
 
 
-as.matrix.massvectorlist<-function(x)
-  {
-    ##t Matrices
-    ##- Turns the massvectorlist into a matrix. On each massvectorlist the \code{summary} method is called.
-    ##- The result of \code{summary} are combined into a matrix.
-    ##+ x : massvectorlist
-    ##v matrix : matrix with columns :"lengthmv","mass.Min.",...,"area.Max." 
-    ##sa as.data.frame.massvectorlist,\link[base]{as.matrix},link[base]{as.data.frame}
-    ##e data(mvl)
-    ##e tmp<-as.matrix(mvl)
-    ##e print(colnames(mvl))
-    ##e plot(tmp[,"lengthmv"],tmp[,"mass.Min."])
-    print("test")
-    mvl<-x
-    rm(x)
-    res <- lapply(mvl,summary)
-    res <- t(sapply(res,unlist))
-    
-    res
-  }
-
-
-as.data.frame.massvectorlist<-function(x,...)
-  {
-    
-    ##t Data Frames
-    ##- Turns the massvectorlist into a data.frame
-    ##d These functions create a data frame, tightly coupled
-    ##d collections of variables which share many of the properties of
-    ##d matrices and of lists, used as the fundamental data structure by
-    ##d most of R's modeling software.
-    ##+ x : object of class massvectorlist
-    ##+ ... : further arguments
-    ##sa as.matrix.massvectorlist, as.matrix
-    ##e data(mvl)
-    ##e tmp <- as.data.frame(mvl)
-    ##e names(mvl)
-    ##e plot(tmp$lengthmv,tmp$mass.Min.)
-
-    
-    res<-NULL
-    tmp<-as.matrix(x)
-    ntmp<-names(x)
-    res<-data.frame(info=as.character(ntmp),tmp)
-    res
-  }
 
 as.list.massvectorlist<-function(x,...)
   {
@@ -178,20 +132,6 @@ project.massvectorlist <- function(object,project,...)
     object
   }
 
-summary.massvectorlist<-function(object,...)
-  {
-    ##t Massvector Summaries
-    ##- Generates a summary: min, max etc for the data.frame generated by as.data.frame.massvectorlist
-    ##+ object : massvectorlist
-    ##+ ... : further arguments
-    ##sa summary.massvector,as.data.frame.massvectorlist 
-    ##e data(mvl)
-    ##e summary(mvl)
-    res<-list(info = info(object))
-    res<-c(res,list(summary=summary(as.matrix(object))))
-    return(res)
-  }
-
 histLengths <- function(x,main=info(x),xlab="length of massvectors",...)
   {
     ##t Histograms
@@ -643,10 +583,10 @@ applyrecalib.massvectorlist <- function(object,calc,...)
         tmp <- object[[nami]]
         tmp<-applyrecalib(tmp,calc[[x]])
         object[[nami]]<-tmp
-        if(x%%10==0)
-          cat(formatC(x,width=3)," ",sep="")
-        if(x%%100==0)
-          cat("\n")
+        #if(x%%10==0)
+        #  cat(formatC(x,width=3)," ",sep="")
+        #if(x%%100==0)
+        #  cat("\n")
       }
     cat("\n")
     object
